package com.answercenter.networkingadvanced.ui.activity

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.widget.Toast
import androidx.activity.viewModels
import androidx.lifecycle.lifecycleScope
import androidx.recyclerview.widget.LinearLayoutManager
import com.answercenter.networkingadvanced.adapter.SearchAdapter
import com.answercenter.networkingadvanced.databinding.ActivityMainBinding
import com.answercenter.networkingadvanced.net.base.ApiCallResult
import com.answercenter.networkingadvanced.ui.viewmodel.ApiViewModel
import com.answercenter.networkingadvanced.utils.ViewExt.hide
import com.answercenter.networkingadvanced.utils.ViewExt.show
import dagger.hilt.android.AndroidEntryPoint
import kotlinx.coroutines.flow.collectLatest
import kotlinx.coroutines.launch

@AndroidEntryPoint
class MainActivity:AppCompatActivity(){
    private val viewModel by viewModels<ApiViewModel>()
    lateinit var binding:ActivityMainBinding
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding= ActivityMainBinding.inflate(layoutInflater)
        setContentView(binding.root)
        binding.run {
            recycler.run {
                layoutManager=LinearLayoutManager(this@MainActivity)
                adapter=SearchAdapter()
            }
            searchBtn.setOnClickListener {
                val text=searchEdt.text.toString()
                if (text.isNotBlank()){
                    lifecycleScope.launch {
                        viewModel.search(text)
                    }
                }
            }
        }
        lifecycleScope.launchWhenStarted {
            viewModel.searchFlow.collectLatest {result->
                when(result){
                    is ApiCallResult.Success->{
                        binding.progress.hide()
                        val data=result.value.items
                        (binding.recycler.adapter as SearchAdapter).submitList(data)
                   }
                    is ApiCallResult.Failure->{
                        binding.progress.hide()
                      val message=  if (result.isNetworkError){
                            "NetworkError"
                        }else{
                           result.errorBody?.toString()?:"Unknown Error"
                        }
                        Toast.makeText(this@MainActivity,message,Toast.LENGTH_LONG).show()
                    }
                    is ApiCallResult.Loading->{
                        binding.progress.show()
                    }
                    else -> {}
                }
            }
        }
    }
}